@@ -303,6 +303,8 @@ class TransportWebSocket(TransportBase):
 
         except Exception as e:
             self._debug_message(f'Failed to connect to {self._uri}: {e}')
+            # Always notify about disconnection to enable reconnection logic
+            await self._transport_disconnected(f'{e}', has_error=True)
             raise ConnectionError(f'{e}')
 
     async def accept(self, websocket) -> None:
